pub struct Arc {
pub basis: Basis2d,
pub center: DVec3,
pub radius: f64,
pub angle: f64,
pub stroke_rgba: AlphaColor<Srgb>,
pub stroke_width: f32,
}Expand description
An arc
Fields
basis: Basis2dProjection
center: DVec3Center
radius: f64Radius
angle: f64Angle
stroke_rgba: AlphaColor<Srgb>Stroke rgba
stroke_width: f32Stroke width
Implementations
Sourceimpl Arc
impl Arc
Sourcepub fn scale(&mut self, scale: f64) -> &mut Self
pub fn scale(&mut self, scale: f64) -> &mut Self
Scale the arc by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the arc a arc.
Sourcepub fn scale_by_anchor<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
pub fn scale_by_anchor<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
Scale the arc by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the arc a arc.