pub struct ArcBetweenPoints {
pub basis: Basis2d,
pub start: DVec3,
pub end: DVec3,
pub angle: f64,
pub stroke_rgba: AlphaColor<Srgb>,
pub stroke_width: f32,
}Expand description
An arc between points
Fields
basis: Basis2dProjection
start: DVec3Start point
end: DVec3End point
angle: f64Arc angle
stroke_rgba: AlphaColor<Srgb>Stroke rgba
stroke_width: f32Stroke width
Implementations
Sourceimpl ArcBetweenPoints
impl ArcBetweenPoints
Sourcepub fn scale(&mut self, scale: f64) -> &mut Self
pub fn scale(&mut self, scale: f64) -> &mut Self
Scale the arc by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the arc a arc.
Sourcepub fn scale_at<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
pub fn scale_at<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
Scale the arc by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the arc a arc.