pub struct Circle {
pub basis: Basis2d,
pub center: DVec3,
pub radius: f64,
pub stroke_rgba: AlphaColor<Srgb>,
pub stroke_width: f32,
pub fill_rgba: AlphaColor<Srgb>,
}Expand description
An circle
Fields
basis: Basis2dBasis
center: DVec3Center
radius: f64Radius
stroke_rgba: AlphaColor<Srgb>Stroke rgba
stroke_width: f32Stroke width
fill_rgba: AlphaColor<Srgb>Fill rgba
Implementations
Sourceimpl Circle
impl Circle
Sourcepub fn scale(&mut self, scale: f64) -> &mut Self
pub fn scale(&mut self, scale: f64) -> &mut Self
Scale the circle by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the circle a circle.
Sourcepub fn scale_by_anchor<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
pub fn scale_by_anchor<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
Scale the circle by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ranim_core::traits::ScaleTransform’s DVec3,
because this keeps the circle a circle.