pub struct Square {
pub basis: Basis2d,
pub center: DVec3,
pub size: f64,
pub stroke_rgba: AlphaColor<Srgb>,
pub stroke_width: f32,
pub fill_rgba: AlphaColor<Srgb>,
}Expand description
A Square
Fields
basis: Basis2dBasis
center: DVec3Center
size: f64Size
stroke_rgba: AlphaColor<Srgb>Stroke rgba
stroke_width: f32Stroke width
fill_rgba: AlphaColor<Srgb>Fill rgba
Implementations
Sourceimpl Square
impl Square
Sourcepub fn scale(&mut self, scale: f64) -> &mut Self
pub fn scale(&mut self, scale: f64) -> &mut Self
Scale the square by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ScaleTransform’s DVec3,
because this keeps the square a square.
Sourcepub fn scale_at<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
pub fn scale_at<T>(&mut self, scale: f64, anchor: T) -> &mut Selfwhere
T: Locate<Self>,
Scale the square by the given scale, with the given anchor as the center.
Note that this accepts a f64 scale dispite of ScaleTransform’s DVec3,
because this keeps the square a square.